@@ -17,10 +17,10 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
-static const char _ext2_meta_c[] = "$Id: ext2_meta.c,v 1.1 1999/09/02 12:07:14 buytenh Exp $";
-
 #include "config.h"
 
+#ifndef DISCOVER_ONLY
+
 #include <stdio.h>
 #include <stdlib.h>
 #include "ext2.h"
@@ -141,3 +141,4 @@ int ext2_metadata_push(struct ext2_fs *fs, blk_t newsize)
 
 	return 1;
 }
+#endif /* !DISCOVER_ONLY */
