@@ -82,7 +82,7 @@ extern void ped_disk_bsd_init ();
 extern void ped_disk_gpt_init ();
 extern void ped_disk_loop_init ();
 extern void ped_disk_mac_init ();
-extern void ped_disk_mips_init ();
+extern void ped_disk_dvh_init ();
 extern void ped_disk_msdos_init ();
 extern void ped_disk_pc98_init ();
 extern void ped_disk_sun_init ();
@@ -97,7 +97,7 @@ init_disk_types ()
 	ped_disk_pc98_init ();
 #endif
 	ped_disk_msdos_init ();
-	ped_disk_mips_init ();
+	ped_disk_dvh_init ();
 	ped_disk_mac_init ();
 	ped_disk_gpt_init ();
 	ped_disk_bsd_init ();
@@ -133,7 +133,7 @@ extern void ped_disk_bsd_done ();
 extern void ped_disk_gpt_done ();
 extern void ped_disk_loop_done ();
 extern void ped_disk_mac_done ();
-extern void ped_disk_mips_done ();
+extern void ped_disk_dvh_done ();
 extern void ped_disk_msdos_done ();
 extern void ped_disk_pc98_done ();
 extern void ped_disk_sun_done ();
@@ -146,7 +146,7 @@ done_disk_types ()
 	ped_disk_pc98_done ();
 #endif
 	ped_disk_msdos_done ();
-	ped_disk_mips_done ();
+	ped_disk_dvh_done ();
 	ped_disk_mac_done ();
 	ped_disk_loop_done ();
 	ped_disk_gpt_done ();
